package App::XPANQueryUtils;

use 5.010001;
use strict;
use warnings;

our $VERSION = '0.04'; # VERSION
our $DATE = '2014-11-09'; # DATE

1;
# ABSTRACT: XPAN::Query command-line utilities

__END__

=pod

=encoding UTF-8

=head1 NAME

App::XPANQueryUtils - XPAN::Query command-line utilities

=head1 VERSION

This document describes version 0.04 of App::XPANQueryUtils (from Perl distribution App-XPANQueryUtils), released on 2014-11-09.

=head1 SYNOPSIS

This distribution provides the following command-line utilities:

 list-xpan-authors
 list-xpan-packages
 list-xpan-dists

=head1 SEE ALSO

L<XPAN::Query>

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/App-XPANQueryUtils>.

=head1 SOURCE

Source repository is at L<https://github.com/sharyanto/perl-App-XPANQueryUtils>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-XPANQueryUtils>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2014 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
